@@ -195,9 +195,7 @@ def test_with_custom_class_methods(app):
 
         def get(self, request):
             self._iternal_method()
-            return text(
-                f"I am get method and global var " f"is {self.global_var}"
-            )
+            return text(f"I am get method and global var is {self.global_var}")
 
     app.add_route(DummyView.as_view(), "/")
     request, response = app.test_client.get("/")
